1.18.0 “Invisible Donkey” — Rucio 1.2 documentation

# 1.18.0 “Invisible Donkey”

## Update Instructions

This feature release requires a database schema update. Please consult the documentation about updating your database schema.

## General

### Features

- Core & Internals: Generic metadata support #1195
- Core & Internals: Extend the bad_replicas table with bytes #1370
- Rules: add_rule on a constituent should make rule on archive #1376

### Enhancements

- Release management: Change urllib3 version to >=1.23 #1523
- Release management: Change flask version to >=0.12.3 due to CVE-2018-1000656 #1524

### Bugs

- Release management: pip install rucio fails with newer versions of pip #1463

## Clients

### Enhancements

- Clients: removing download() method from downloadclient #1378
- Clients: Human friendly limit setting #1529

### Bugs

- Clients: Using summary file in upload API will crash #1532

## WebUI

### Features

- WebUI: Rucio UI RSE admin view #80